==> jc-1.4.0.tar.gz: javax/swing/JTree__24DynamicUtilTreeNode.h <==
// public class javax.swing.JTree$DynamicUtilTreeNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ed92dee27c6f3eab javax_swing_JTree__24DynamicUtilTreeNode
// @dep_class 45ea9ccb4d570447 javax_swing_tree_DefaultMutableTreeNode

// header file dependencies
// @dep_header javax_swing_tree_DefaultMutableTreeNode

#include "javax/swing/tree/DefaultMutableTreeNode.h"

#ifndef _JC_javax_swing_JTree__24DynamicUtilTreeNode_H_
#define _JC_javax_swing_JTree__24DynamicUtilTreeNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Enumeration$object;
struct _jc_javax_swing_tree_DefaultMutableTreeNode$object;

// Typedefs
typedef struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_refs	_jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_refs;
typedef struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_nonrefs	_jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_nonrefs;
typedef struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$refs	_jc_javax_swing_JTree__24DynamicUtilTreeNode$refs;
typedef struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$nonrefs	_jc_javax_swing_JTree__24DynamicUtilTreeNode$nonrefs;
typedef struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object	_jc_javax_swing_JTree__24DynamicUtilTreeNode$object;

typedef const struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vmethods	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vmethods;
typedef const struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vtable	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vtable;
typedef const struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vtype	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vtype;

// Constructors
extern void _jc_javax_swing_JTree__24DynamicUtilTreeNode$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_object *_jc_javax_swing_JTree__24DynamicUtilTreeNode$method$children$9e2997f174595d60(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *);
extern jint _jc_javax_swing_JTree__24DynamicUtilTreeNode$method$getChildCount$feef39475b7bd4e6(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *);
extern jboolean _jc_javax_swing_JTree__24DynamicUtilTreeNode$method$isLeaf$fe54aef948a9fef3(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *);
extern void _jc_javax_swing_JTree__24DynamicUtilTreeNode$method$loadChildren$84109855f526e2f8(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JTree__24DynamicUtilTreeNode$method_info$children$9e2997f174595d60;
extern _jc_method _jc_javax_swing_JTree__24DynamicUtilTreeNode$method_info$getChildCount$feef39475b7bd4e6;
extern _jc_method _jc_javax_swing_JTree__24DynamicUtilTreeNode$method_info$isLeaf$fe54aef948a9fef3;
extern _jc_method _jc_javax_swing_JTree__24DynamicUtilTreeNode$method_info$loadChildren$84109855f526e2f8;

// Static methods
extern void _jc_javax_swing_JTree__24DynamicUtilTreeNode$method$createChildren$6c0365070e24f793(_jc_env *, struct _jc_javax_swing_tree_DefaultMutableTreeNode$object *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vmethods {
	struct _jc_object	*(*children$9e2997f174595d60)(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *);
	jint	(*getChildCount$feef39475b7bd4e6)(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *);
	jboolean	(*isLeaf$fe54aef948a9fef3)(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *);
	void	(*loadChildren$84109855f526e2f8)(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *);
};

// Vtable
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_tree_DefaultMutableTreeNode$vmethods	javax_swing_tree_DefaultMutableTreeNode;
	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vmethods	javax_swing_JTree__24DynamicUtilTreeNode;
};

// Vtype
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vtype {
	_jc_type			type;
	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_refs {
	struct _jc_java_lang_Object$object	*childValue;
};

// Reference instance fields (object)
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$refs {
    _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_refs	javax_swing_JTree__24DynamicUtilTreeNode;
    _jc_javax_swing_tree_DefaultMutableTreeNode$sub_refs	javax_swing_tree_DefaultMutableTreeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_nonrefs {
	jboolean	loadedChildren;
	jboolean	hasChildren;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_tree_DefaultMutableTreeNode$sub_nonrefs	javax_swing_tree_DefaultMutableTreeNode;
    _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_nonrefs	javax_swing_JTree__24DynamicUtilTreeNode;
};

// Object instance structure
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object {
	_jc_javax_swing_JTree__24DynamicUtilTreeNode$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vtype	*vtype;
	_jc_javax_swing_JTree__24DynamicUtilTreeNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JTree__24DynamicUtilTreeNode$vtype _jc_javax_swing_JTree__24DynamicUtilTreeNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JTree__24DynamicUtilTreeNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JTree__24DynamicUtilTreeNode$class_object;

#endif	/* _JC_javax_swing_JTree__24DynamicUtilTreeNode_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JTree__24DynamicUtilTreeNode.h <==
// public class javax.swing.JTree$DynamicUtilTreeNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ed92dee27c6f3eab javax_swing_JTree__24DynamicUtilTreeNode
// @dep_class 45ea9ccb4d570447 javax_swing_tree_DefaultMutableTreeNode

// header file dependencies
// @dep_header javax_swing_tree_DefaultMutableTreeNode

#include "javax/swing/tree/DefaultMutableTreeNode.h"

#ifndef _JC_javax_swing_JTree__24DynamicUtilTreeNode_H_
#define _JC_javax_swing_JTree__24DynamicUtilTreeNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Enumeration$object;
struct _jc_javax_swing_tree_DefaultMutableTreeNode$object;

// Typedefs
typedef struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_refs	_jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_refs;
typedef struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_nonrefs	_jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_nonrefs;
typedef struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$refs	_jc_javax_swing_JTree__24DynamicUtilTreeNode$refs;
typedef struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$nonrefs	_jc_javax_swing_JTree__24DynamicUtilTreeNode$nonrefs;
typedef struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object	_jc_javax_swing_JTree__24DynamicUtilTreeNode$object;

typedef const struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vmethods	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vmethods;
typedef const struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vtable	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vtable;
typedef const struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vtype	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vtype;

// Constructors
extern void _jc_javax_swing_JTree__24DynamicUtilTreeNode$method$_init$1b34a4ef37055d19(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_swing_JTree__24DynamicUtilTreeNode$method$children$9e2997f174595d60(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_JTree__24DynamicUtilTreeNode$method$getChildCount$feef39475b7bd4e6(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *) _JC_JCNI_ATTR;
extern jboolean _jc_javax_swing_JTree__24DynamicUtilTreeNode$method$isLeaf$fe54aef948a9fef3(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_JTree__24DynamicUtilTreeNode$method$loadChildren$84109855f526e2f8(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JTree__24DynamicUtilTreeNode$method_info$children$9e2997f174595d60;
extern _jc_method _jc_javax_swing_JTree__24DynamicUtilTreeNode$method_info$getChildCount$feef39475b7bd4e6;
extern _jc_method _jc_javax_swing_JTree__24DynamicUtilTreeNode$method_info$isLeaf$fe54aef948a9fef3;
extern _jc_method _jc_javax_swing_JTree__24DynamicUtilTreeNode$method_info$loadChildren$84109855f526e2f8;

// Static methods
extern void _jc_javax_swing_JTree__24DynamicUtilTreeNode$method$createChildren$6c0365070e24f793(_jc_env *, struct _jc_javax_swing_tree_DefaultMutableTreeNode$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vmethods {
	struct _jc_object	*(*children$9e2997f174595d60)(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *) _JC_JCNI_ATTR;
	jint	(*getChildCount$feef39475b7bd4e6)(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *) _JC_JCNI_ATTR;
	jboolean	(*isLeaf$fe54aef948a9fef3)(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *) _JC_JCNI_ATTR;
	void	(*loadChildren$84109855f526e2f8)(_jc_env *, struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_tree_DefaultMutableTreeNode$vmethods	javax_swing_tree_DefaultMutableTreeNode;
	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vmethods	javax_swing_JTree__24DynamicUtilTreeNode;
};

// Vtype
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$vtype {
	_jc_type			type;
	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_refs {
	struct _jc_java_lang_Object$object	*childValue;
};

// Reference instance fields (object)
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$refs {
    _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_refs	javax_swing_JTree__24DynamicUtilTreeNode;
    _jc_javax_swing_tree_DefaultMutableTreeNode$sub_refs	javax_swing_tree_DefaultMutableTreeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_nonrefs {
	jboolean	loadedChildren;
	jboolean	hasChildren;
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_tree_DefaultMutableTreeNode$sub_nonrefs	javax_swing_tree_DefaultMutableTreeNode;
    _jc_javax_swing_JTree__24DynamicUtilTreeNode$sub_nonrefs	javax_swing_JTree__24DynamicUtilTreeNode;
};

// Object instance structure
struct _jc_javax_swing_JTree__24DynamicUtilTreeNode$object {
	_jc_javax_swing_JTree__24DynamicUtilTreeNode$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JTree__24DynamicUtilTreeNode$vtype	*vtype;
	_jc_javax_swing_JTree__24DynamicUtilTreeNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JTree__24DynamicUtilTreeNode$vtype _jc_javax_swing_JTree__24DynamicUtilTreeNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JTree__24DynamicUtilTreeNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JTree__24DynamicUtilTreeNode$class_object;

#endif	/* _JC_javax_swing_JTree__24DynamicUtilTreeNode_H_ */
